@@ -1,17 +1,18 @@
-#!/usr/bin/perl
+package Devel::INC::Sorted; # git description: Devel-INC-Sorted-0.02-7-geee6b42
+# ABSTRACT: Keep your hooks in the beginning of @INC
 
-package Devel::INC::Sorted;
-use base qw(Exporter Tie::Array);
+use base 'Tie::Array';
 
 use strict;
 use warnings;
 
 use sort 'stable';
 
+use Exporter;
 use Scalar::Util qw(blessed reftype);
 use Tie::RefHash;
 
-our $VERSION = "0.02";
+our $VERSION = '0.03';
 
 our @EXPORT_OK = qw(inc_add_floating inc_float_entry inc_unfloat_entry untie_inc);
 
@@ -20,7 +21,7 @@ tie our %floating, 'Tie::RefHash';
 sub import {
 	my ( $self, @args ) = @_;
 	$self->tie_inc( grep { ref } @args ); # if a code ref is given, pass it to TIEARRAY
-	$self->export_to_level(1, $self, @args);
+	goto &Exporter::import;
 }
 
 sub _args {
@@ -49,7 +50,7 @@ sub inc_add_floating {
 
 sub inc_float_entry {
 	my ( $self, @args ) = &_args;
-	
+
 	@floating{@args} = ( (1) x @args );
 
 	$self->_fixup;
@@ -79,7 +80,7 @@ sub untie_inc {
 
 # This code was adapted from Tie::Array::Sorted::Lazy
 # the reason it's not a subclass is because neither ::Sorted nor ::Sorted::Lazy
-# provide a stably sorted array, which is bad for our default comparator
+# provide a stably sorted array, which is bad for our default comparison operator
 
 sub TIEARRAY {
 	my ( $class, $comparator, @orig ) = @_;
@@ -126,8 +127,8 @@ sub FETCH {
 	$_[0]->{array}->[ $_[1] ];
 }
 
-sub FETCHSIZE { 
-	scalar @{ $_[0]->{array} } 
+sub FETCHSIZE {
+	scalar @{ $_[0]->{array} }
 }
 
 sub STORESIZE {
@@ -150,8 +151,8 @@ sub DELETE {
 	delete $_[0]->{array}->[ $_[1] ];
 }
 
-sub CLEAR { 
-	@{ $_[0]->{array} } = () 
+sub CLEAR {
+	@{ $_[0]->{array} } = ()
 }
 
 __PACKAGE__
@@ -160,9 +161,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Devel::INC::Sorted - Keep your hooks in the begining of C<@INC>
+Devel::INC::Sorted - Keep your hooks in the beginning of @INC
+
+=head1 VERSION
+
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -182,8 +189,8 @@ Devel::INC::Sorted - Keep your hooks in the begining of C<@INC>
 
 This module keeps C<@INC> sorted much like L<Tie::Array::Sorted>.
 
-The default comparator partitions the members into floating and non floating,
-allowing you to easily keep certain hooks in the begining of C<@INC>.
+The default comparison operator partitions the members into floating and non floating,
+allowing you to easily keep certain hooks in the beginning of C<@INC>.
 
 The sort used is a stable one, to make sure that the order of C<@INC> for
 unsorted items remains unchanged.
@@ -200,7 +207,7 @@ Add entries to C<@INC> and call C<inc_float_entry> on them.
 
 =item inc_float_entry
 
-Mark the arguments as floating (in the internal refhash).
+Mark the arguments as floating (in the internal hashref).
 
 =item inc_unfloat_entry
 
@@ -213,22 +220,26 @@ modifications to C<@INC> will not cause resorting to happen.
 
 =back
 
-=head1 VERSION CONTROL
+=head1 SUPPORT
 
-This module is maintained using Darcs. You can get the latest version from
-L<http://nothingmuch.woobling.org/code>, and use C<darcs send> to commit
-changes.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-INC-Sorted>
+(or L<bug-Devel-INC-Sorted@rt.cpan.org|mailto:bug-Devel-INC-Sorted@rt.cpan.org>).
 
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT
+=head1 CONTRIBUTOR
 
-	Copyright (c) 2008 Yuval Kogman. All rights reserved
-	This program is free software; you can redistribute
-	it and/or modify it under the same terms as Perl itself.
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
